@@ -1,31 +1,31 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2018 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
-// 
+//
 // This program is free software.  The contents of this file are subject
 // to the terms of the GNU General Public License as published by the
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version.  You may redistribute it and/or modify it
 // only in compliance with the GNU General Public License.
-// 
+//
 // This program is distributed in the hope that it will be useful.
 // However, this program is distributed AS-IS WITHOUT ANY
 // WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
 // FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
 // for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 // USA.
-// 
+//
 // Nothing in the GNU General Public License or any other license to use
 // the code or files shall permit you to use Tripwire's trademarks,
 // service marks, or other intellectual property without Tripwire's
 // prior written consent.
-// 
+//
 // If you have any questions, please contact Tripwire, Inc. at either
 // info@tripwire.org or www.tripwire.org.
 //
@@ -51,7 +51,7 @@
 #include "fco/fconametranslator.h"
 
 //
-// TODO -- change the report interface so that it takes an error bucket instead of an error queue and then 
+// TODO -- change the report interface so that it takes an error bucket instead of an error queue and then
 //      pass our error bucket to it.
 //
 // TODO -- we need to pass in the prop displayer and do ??? with it at the appropriate times...
@@ -60,38 +60,40 @@
 ///////////////////////////////////////////////////////////////////////////////
 // ProcessAddedFCO
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::ProcessAddedFCO( cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse )
+void cIntegrityCheck::ProcessAddedFCO(cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse)
 {
-    ASSERT( pIter && (! pIter->Done()) );
+    ASSERT(pIter && (!pIter->Done()));
     //
     // don't do anything if this FCO is not a part of the spec...
     //
-    if( mpCurSpec->ShouldStopDescent( pIter->GetName() ) )
+    if (mpCurSpec->ShouldStopDescent(pIter->GetName()))
         return;
     //
     // note that pIter points to the added fco
     //
     iFCO* pFCO = pIter->CreateFCO();
     mnObjectsScanned++;
-    mReportIter.SetObjectsScanned( mReportIter.GetObjectsScanned() + 1 );
-    if( pFCO )
+    mReportIter.SetObjectsScanned(mReportIter.GetObjectsScanned() + 1);
+    if (pFCO)
     {
-        cTripwireUtil::CalcProps( pFCO, mpCurSpec, mpPropCalc, 0 ); //TODO -- a property displayer should be passed in here.
-        mReportIter.GetAddedSet()->Insert( pFCO );
+        cTripwireUtil::CalcProps(
+            pFCO, mpCurSpec, mpPropCalc, 0); //TODO -- a property displayer should be passed in here.
+        mReportIter.GetAddedSet()->Insert(pFCO);
         pFCO->Release();
         //
         // descend here, if we can...
         //
-        if( bRecurse )
+        if (bRecurse)
         {
-            if( pIter->CanDescend() )
+            if (pIter->CanDescend())
             {
                 // note that we don't want to descend into the dbIter, so we will seek it
                 // to done...
                 //
-                while( ! dbIter.Done() ) dbIter.Next();
-                std::auto_ptr<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
-                ProcessDir( dbIter, pCopy.get() );
+                while (!dbIter.Done())
+                    dbIter.Next();
+                TW_UNIQUE_PTR<iFCODataSourceIter> pCopy(pIter->CreateCopy());
+                ProcessDir(dbIter, pCopy.get());
             }
         }
     }
@@ -100,34 +102,34 @@ void cIntegrityCheck::ProcessAddedFCO( cDbDataSourceIter dbIter, iFCODataSourceI
 ///////////////////////////////////////////////////////////////////////////////
 // ProcessRemovedFCO
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::ProcessRemovedFCO( cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse )
+void cIntegrityCheck::ProcessRemovedFCO(cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse)
 {
-    ASSERT( ! dbIter.Done() );
+    ASSERT(!dbIter.Done());
     //
     // don't do anything if this FCO is not a part of the spec...
     //
-    if( mpCurSpec->ShouldStopDescent( dbIter.GetName() ) )
+    if (mpCurSpec->ShouldStopDescent(dbIter.GetName()))
         return;
     //
     // we have to be careful here, since not all db nodes are guarenteed to have fco data associated with them.
     //
-    if( dbIter.HasFCOData() )
+    if (dbIter.HasFCOData())
     {
         // add this to the "removed" set
         //
         iFCO* pFCO = dbIter.CreateFCO();
-        mReportIter.GetRemovedSet()->Insert( pFCO );
+        mReportIter.GetRemovedSet()->Insert(pFCO);
         pFCO->Release();
     }
     // descend if we can...
     //
-    if( bRecurse )
+    if (bRecurse)
     {
-        if( dbIter.CanDescend() )
+        if (dbIter.CanDescend())
         {
             // we don't want pIter to be descended into, so we will pass null as the second param...
             //
-            ProcessDir( dbIter, 0 );
+            ProcessDir(dbIter, 0);
         }
     }
 }
@@ -135,49 +137,48 @@ void cIntegrityCheck::ProcessRemovedFCO( cDbDataSourceIter dbIter, iFCODataSourc
 ///////////////////////////////////////////////////////////////////////////////
 // ProcessChangedFCO
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::ProcessChangedFCO( cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse ) 
+void cIntegrityCheck::ProcessChangedFCO(cDbDataSourceIter dbIter, iFCODataSourceIter* pIter, bool bRecurse)
 {
-    ASSERT( pIter && (! pIter->Done()) );
-    ASSERT( ! dbIter.Done() );
+    ASSERT(pIter && (!pIter->Done()));
+    ASSERT(!dbIter.Done());
     cDebug d("cIntegrityCheck::ProcessChangedFCO");
     //
     // don't do anything if this FCO is not a part of the spec...
     //
-    if( mpCurSpec->ShouldStopDescent( pIter->GetName() ) )
+    if (mpCurSpec->ShouldStopDescent(pIter->GetName()))
         return;
 
     // if the database doesn't have this data, then process this as an add
     //
-    if( ! dbIter.HasFCOData() )
+    if (!dbIter.HasFCOData())
     {
-        ProcessAddedFCO( dbIter, pIter, false );    // false means not to recurse
+        ProcessAddedFCO(dbIter, pIter, false); // false means not to recurse
     }
     else
     {
         // here we will actually compare the two FCOs
         //
-        TW_NOTIFY_VERBOSE(  _T("--- %s%s\n"), 
-                            TSS_GetString( cTripwire, tripwire::STR_NOTIFY_CHECKING ).c_str(),
-                            iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay
-                                ( pIter->GetName() ).c_str() );
+        TW_NOTIFY_VERBOSE(_T("--- %s%s\n"),
+                          TSS_GetString(cTripwire, tripwire::STR_NOTIFY_CHECKING).c_str(),
+                          iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay(pIter->GetName()).c_str());
 
         iFCO* pNewFCO = pIter->CreateFCO();
         iFCO* pOldFCO = dbIter.CreateFCO();
-        
+
         mnObjectsScanned++;
-        mReportIter.SetObjectsScanned( mReportIter.GetObjectsScanned() + 1 );
+        mReportIter.SetObjectsScanned(mReportIter.GetObjectsScanned() + 1);
         //
         // if we can't create the operating system object, treat this as a removal; we will
         // increment the os iterator...
         //
-        if( ! pNewFCO )
+        if (!pNewFCO)
         {
             pIter->Next();
-            ProcessRemovedFCO( dbIter, pIter, bRecurse );
+            ProcessRemovedFCO(dbIter, pIter, bRecurse);
             return;
         }
 
-        CompareFCOs( pOldFCO, pNewFCO );
+        CompareFCOs(pOldFCO, pNewFCO);
 
         //-------------------------------------------------------------------------
         // Begin functionality necessary for policy update
@@ -185,37 +186,38 @@ void cIntegrityCheck::ProcessChangedFCO( cDbDataSourceIter dbIter, iFCODataSourc
         bool bDbFCODirty = false;
         // change the valid vector for the db's fco, if the appropriate flag is set
         //
-        if( mFlags & FLAG_INVALIDATE_EXTRA_DB_PROPS )
+        if (mFlags & FLAG_INVALIDATE_EXTRA_DB_PROPS)
         {
-            cFCOPropVector propsToInvalidate    =  pOldFCO->GetPropSet()->GetValidVector() & mpCurSpec->GetPropVector( pOldFCO );
-            propsToInvalidate                   ^= pOldFCO->GetPropSet()->GetValidVector();
-            pOldFCO->GetPropSet()->InvalidateProps( propsToInvalidate );
+            cFCOPropVector propsToInvalidate =
+                pOldFCO->GetPropSet()->GetValidVector() & mpCurSpec->GetPropVector(pOldFCO);
+            propsToInvalidate ^= pOldFCO->GetPropSet()->GetValidVector();
+            pOldFCO->GetPropSet()->InvalidateProps(propsToInvalidate);
 
             bDbFCODirty = true;
         }
         // update the old fco with the new properties...
         //
-        if( mFlags & FLAG_SET_NEW_PROPS )
+        if (mFlags & FLAG_SET_NEW_PROPS)
         {
-            cFCOPropVector propsToCopy  =  pOldFCO->GetPropSet()->GetValidVector() & pNewFCO->GetPropSet()->GetValidVector();
-            propsToCopy                 ^= pNewFCO->GetPropSet()->GetValidVector();
+            cFCOPropVector propsToCopy =
+                pOldFCO->GetPropSet()->GetValidVector() & pNewFCO->GetPropSet()->GetValidVector();
+            propsToCopy ^= pNewFCO->GetPropSet()->GetValidVector();
 
-            pOldFCO->GetPropSet()->CopyProps( pNewFCO->GetPropSet(), propsToCopy );
+            pOldFCO->GetPropSet()->CopyProps(pNewFCO->GetPropSet(), propsToCopy);
 
             bDbFCODirty = true;
         }
         // rewrite the fco to the database, if necessary
         //
-        if( bDbFCODirty )
+        if (bDbFCODirty)
         {
             dbIter.RemoveFCOData();
-            dbIter.SetFCOData( pOldFCO );
-
-            TW_NOTIFY_VERBOSE(  _T("%s%s\n"), 
-                                TSS_GetString( cTripwire, tripwire::STR_NOTIFY_DB_CHANGING ).c_str(),
-                                iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay
-                                    ( pOldFCO->GetName() ).c_str() );
+            dbIter.SetFCOData(pOldFCO);
 
+            TW_NOTIFY_VERBOSE(
+                _T("%s%s\n"),
+                TSS_GetString(cTripwire, tripwire::STR_NOTIFY_DB_CHANGING).c_str(),
+                iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay(pOldFCO->GetName()).c_str());
         }
         //
         // end policy update specific code
@@ -227,12 +229,12 @@ void cIntegrityCheck::ProcessChangedFCO( cDbDataSourceIter dbIter, iFCODataSourc
     //
     // finally, we need to recurse into our child directories...
     //
-    if( bRecurse )
+    if (bRecurse)
     {
-        if( pIter->CanDescend() || dbIter.CanDescend() )
+        if (pIter->CanDescend() || dbIter.CanDescend())
         {
-            std::auto_ptr<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
-            ProcessDir( dbIter, pCopy.get() );
+            TW_UNIQUE_PTR<iFCODataSourceIter> pCopy(pIter->CreateCopy());
+            ProcessDir(dbIter, pCopy.get());
         }
     }
 }
@@ -240,63 +242,62 @@ void cIntegrityCheck::ProcessChangedFCO( cDbDataSourceIter dbIter, iFCODataSourc
 ///////////////////////////////////////////////////////////////////////////////
 // CompareFCOs
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::CompareFCOs( iFCO* pOldFCO, iFCO* pNewFCO )
+void cIntegrityCheck::CompareFCOs(iFCO* pOldFCO, iFCO* pNewFCO)
 {
-    cTripwireUtil::CalcProps( pNewFCO, mpCurSpec, mpPropCalc, 0 );  //TODO -- a property displayer should be passed in here.
+    cTripwireUtil::CalcProps(
+        pNewFCO, mpCurSpec, mpPropCalc, 0); //TODO -- a property displayer should be passed in here.
     //
     // figure out what properties we are comparing...for an explanation of the propsToCheck derivation, see tripwire.cpp line 250.
     //
     cFCOPropVector propsToCheck;
-    if( mFlags & FLAG_COMPARE_VALID_PROPS_ONLY )
+    if (mFlags & FLAG_COMPARE_VALID_PROPS_ONLY)
     {
-        propsToCheck =  pOldFCO->GetPropSet()->GetValidVector() & 
-                        pNewFCO->GetPropSet()->GetValidVector();
+        propsToCheck = pOldFCO->GetPropSet()->GetValidVector() & pNewFCO->GetPropSet()->GetValidVector();
     }
     else
     {
-        propsToCheck =  pOldFCO->GetPropSet()->GetValidVector() | 
-                        pNewFCO->GetPropSet()->GetValidVector();
+        propsToCheck = pOldFCO->GetPropSet()->GetValidVector() | pNewFCO->GetPropSet()->GetValidVector();
     }
-    propsToCheck &= mpCurSpec->GetPropVector( pNewFCO );
+    propsToCheck &= mpCurSpec->GetPropVector(pNewFCO);
     //
     // trim off the loose dir stuff...
     //
-    if( (pOldFCO->GetCaps() & iFCO::CAP_CAN_HAVE_CHILDREN) &&
-        (pNewFCO->GetCaps() & iFCO::CAP_CAN_HAVE_CHILDREN) )
+    if ((pOldFCO->GetCaps() & iFCO::CAP_CAN_HAVE_CHILDREN) && (pNewFCO->GetCaps() & iFCO::CAP_CAN_HAVE_CHILDREN))
     {
-        cFCOPropVector tmp  = (propsToCheck ^ mLooseDirProps);
-        propsToCheck        &= tmp;
+        cFCOPropVector tmp = (propsToCheck ^ mLooseDirProps);
+        propsToCheck &= tmp;
     }
     //
     // construct the compare object and actually do the compare
     //
-    cFCOCompare compareObj( propsToCheck );
-    uint32 result = compareObj.Compare(pOldFCO, pNewFCO);
+    cFCOCompare compareObj(propsToCheck);
+    uint32      result = compareObj.Compare(pOldFCO, pNewFCO);
 
-    if( (result & cFCOCompare::PROPS_UNEQUAL) || (result & cFCOCompare::PROPS_NOT_ALL_VALID) )
+    if ((result & cFCOCompare::PROPS_UNEQUAL) || (result & cFCOCompare::PROPS_NOT_ALL_VALID))
     {
         // this is a violation...
         //
-        mReport.AddChangedFCO(mReportIter, pOldFCO, pNewFCO, compareObj.GetUnequalProps() | compareObj.GetInvalidProps());
+        mReport.AddChangedFCO(
+            mReportIter, pOldFCO, pNewFCO, compareObj.GetUnequalProps() | compareObj.GetInvalidProps());
     }
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // ProcessDir
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::ProcessDir( cDbDataSourceIter dbIter, iFCODataSourceIter* pIter )
+void cIntegrityCheck::ProcessDir(cDbDataSourceIter dbIter, iFCODataSourceIter* pIter)
 {
     cDebug d("cIntegrityCheck::ProcessDir");
 
-    // if either iterator is done, or if the data source iter is NULL, that indicates that the tree 
+    // if either iterator is done, or if the data source iter is NULL, that indicates that the tree
     // has stopped for that iterator, and all FCOs encountered by the other iter are all adds or removals,
     // as appropriate.
     //
     // the first thing we will do is descend, if possible, and if not possible, set them to done().
     //
-    if( pIter )
+    if (pIter)
     {
-        if( pIter->CanDescend() )
+        if (pIter->CanDescend())
         {
             pIter->Descend();
         }
@@ -305,131 +306,136 @@ void cIntegrityCheck::ProcessDir( cDbDataSourceIter dbIter, iFCODataSourceIter*
             pIter = 0;
         }
     }
-    if( ! dbIter.Done() )
+    if (!dbIter.Done())
     {
-        if( dbIter.CanDescend() )
+        if (dbIter.CanDescend())
         {
             dbIter.Descend();
         }
         else
         {
-            while( ! dbIter.Done() ) dbIter.Next();
+            while (!dbIter.Done())
+                dbIter.Next();
         }
     }
     // if they are both done, then we are done dealin'!
     //
-    if( ((! pIter) || (pIter->Done())) && ( dbIter.Done() ) )
+    if (((!pIter) || (pIter->Done())) && (dbIter.Done()))
     {
         //TODO -- what else do I need to do here?
         return;
     }
 
-#ifdef _DEBUG
-    if( dbIter.Done() )
+#ifdef DEBUG
+    if (dbIter.Done())
     {
-        d.TraceDebug( "Processing directory %s\n", pIter->GetParentName().AsString().c_str() );
+        d.TraceDebug("Processing directory %s\n", pIter->GetParentName().AsString().c_str());
     }
     else
     {
-        d.TraceDebug( "Processing directory %s\n", dbIter.GetParentName().AsString().c_str() );
+        d.TraceDebug("Processing directory %s\n", dbIter.GetParentName().AsString().c_str());
     }
 #endif
 
     //
     // now, process the entries in this directory...
     //
-    while( true )
+    while (true)
     {
         // this just cleans up some logic statements below...
         //
-        if( pIter && pIter->Done() )
+        if (pIter && pIter->Done())
             pIter = NULL;
 
         // if they are both done, then we are finished...
         //
-        if( dbIter.Done() && (! pIter ) )
+        if (dbIter.Done() && (!pIter))
             break;
 
-        if( dbIter.Done() )
+        if (dbIter.Done())
         {
-            ASSERT( pIter != 0);
-            d.TraceDetail( "Examining <done> and %s\n", pIter->GetName().AsString().c_str() );
-            //
-            // these are all new entries, add them to the "Added" set...
-            //
-            ProcessAddedFCO( dbIter, pIter );
-            pIter->Next();
+            ASSERT(pIter != 0);
+            if (pIter)
+            {
+                d.TraceDetail("Examining <done> and %s\n", pIter->GetName().AsString().c_str());
+                //
+                // these are all new entries, add them to the "Added" set...
+                //
+                ProcessAddedFCO(dbIter, pIter);
+                pIter->Next();
+            }
         }
-        else if( ! pIter )
+        else if (!pIter)
         {
-            ASSERT( ! dbIter.Done() );
-            d.TraceDetail( _T("--Examining %s and <done>\n"), dbIter.GetName().AsString().c_str() );
+            ASSERT(!dbIter.Done());
+            d.TraceDetail(_T("--Examining %s and <done>\n"), dbIter.GetName().AsString().c_str());
             //
-            // these are all removed objects. 
+            // these are all removed objects.
             //
-            ProcessRemovedFCO( dbIter, pIter );
+            ProcessRemovedFCO(dbIter, pIter);
             dbIter.Next();
         }
         else
         {
-            d.TraceDetail( _T("--Examining %s and %s\n"), dbIter.GetName().AsString().c_str(), pIter->GetName().AsString().c_str() );
+            d.TraceDetail(_T("--Examining %s and %s\n"),
+                          dbIter.GetName().AsString().c_str(),
+                          pIter->GetName().AsString().c_str());
 
-            ASSERT( pIter->GetParentName() == dbIter.GetParentName() );
+            ASSERT(pIter->GetParentName() == dbIter.GetParentName());
             //
             // get the relationship between the current nodes of the two iterators...
             //
-            iFCODataSourceIter::Relationship rel = dbIter.GetRelationship( *pIter );
+            iFCODataSourceIter::Relationship rel = dbIter.GetRelationship(*pIter);
             //
             // if rel == LT, then the old has something the new doesn't (ie -- a removal!)
             // if rel == GT, then there is an addition
             //
-            if( rel == iFCODataSourceIter::REL_LT )
+            if (rel == iFCODataSourceIter::REL_LT)
             {
-                ProcessRemovedFCO( dbIter, pIter );
+                ProcessRemovedFCO(dbIter, pIter);
                 dbIter.Next();
             }
-            else if( rel == iFCODataSourceIter::REL_GT )
+            else if (rel == iFCODataSourceIter::REL_GT)
             {
-                ProcessAddedFCO( dbIter, pIter );
+                ProcessAddedFCO(dbIter, pIter);
                 pIter->Next();
-
             }
             else
             {
                 // we actually have to compare the FCOs at this point...
                 // NOTE -- if the db iter has no data, then this is an add again.
-                //      
-                ProcessChangedFCO( dbIter, pIter );
+                //
+                ProcessChangedFCO(dbIter, pIter);
 
                 dbIter.Next();
                 pIter->Next();
             }
 
-            ASSERT( pIter->GetParentName() == dbIter.GetParentName() );
+            ASSERT(pIter->GetParentName() == dbIter.GetParentName());
         }
     }
-    d.TraceDebug( "Done Processing Directory\n");
+    d.TraceDebug("Done Processing Directory\n");
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // ctor
 ///////////////////////////////////////////////////////////////////////////////
-cIntegrityCheck::cIntegrityCheck(cGenre::Genre genreNum,  const cFCOSpecList& specList, cHierDatabase& db, cFCOReport& report, cErrorBucket* pBucket )
-:
-    mGenre          ( genreNum ), 
-    mSpecList       ( specList ),
-    mDb             ( db ),
-    mReport         ( report ),
-    mpPropCalc      ( iTWFactory::GetInstance()->CreatePropCalc() ),
-    mpCurSpec       ( 0 ),
-    mReportIter     ( report, genreNum ),
-    mFlags          ( 0 ),
-    mnObjectsScanned( 0 )
+cIntegrityCheck::cIntegrityCheck(
+    cGenre::Genre genreNum, const cFCOSpecList& specList, cHierDatabase& db, cFCOReport& report, cErrorBucket* pBucket)
+    : mGenre(genreNum),
+      mSpecList(specList),
+      mDb(db),
+      mReport(report),
+      mpPropCalc(iTWFactory::GetInstance()->CreatePropCalc()),
+      mpCurSpec(0),
+      mReportIter(report, genreNum),
+      mFlags(0),
+      mnObjectsScanned(0)
 {
     // mBucket is a pass-thru bucket; its only job is to pass the errors onto its child.
     //
-    mBucket.SetChild            ( pBucket );
-    mpPropCalc->SetErrorBucket  ( &mBucket );
+    mBucket.SetChild(pBucket);
+    mpPropCalc->SetErrorBucket(&mBucket);
 }
 
 
@@ -445,17 +451,17 @@ cIntegrityCheck::~cIntegrityCheck()
 ///////////////////////////////////////////////////////////////////////////////
 // Execute
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::Execute( uint32 flags )
+void cIntegrityCheck::Execute(uint32 flags)
 {
     mFlags = flags;
     // create the data source iterator
     //
-    std::auto_ptr<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
+    TW_UNIQUE_PTR<iFCODataSourceIter> pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
     //
     // set up the database's iterator...
     // I assume the current genre is correct...
     //
-    cDbDataSourceIter dbIter( &mDb );   
+    cDbDataSourceIter dbIter(&mDb);
 
     //
     // set the iterator's error bucket...
@@ -468,98 +474,103 @@ void cIntegrityCheck::Execute( uint32 flags )
     // be removed from the ones used to compare, so if loose dirs is not specified, we can set this
     // to the empty vector.
     //
-    if( flags & FLAG_LOOSE_DIR )
+    if (flags & FLAG_LOOSE_DIR)
     {
         mLooseDirProps = iTWFactory::GetInstance()->GetLooseDirMask();
     }
 
     //
     // set up flags for the property calculator and iterators
-    //    
-    if( flags & FLAG_ERASE_FOOTPRINTS_IC )
+    //
+    if (flags & FLAG_ERASE_FOOTPRINTS_IC)
     {
-        mpPropCalc->SetCalcFlags( iFCOPropCalc::DO_NOT_MODIFY_PROPERTIES );  
-        dbIter.SetIterFlags     ( iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS );
-        pDSIter->SetIterFlags   ( iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS );
+        mpPropCalc->SetCalcFlags(iFCOPropCalc::DO_NOT_MODIFY_PROPERTIES);
+        dbIter.SetIterFlags(iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS);
+        pDSIter->SetIterFlags(iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS);
     }
-    
+
+    if (flags & FLAG_DIRECT_IO)
+    {
+        mpPropCalc->SetCalcFlags(mpPropCalc->GetCalcFlags() | iFCOPropCalc::DIRECT_IO);
+    }
+
     //
     // iterate over all of the specs...
     //
-    cFCOSpecListCanonicalIter   specIter(mSpecList);
-    for(specIter.SeekBegin(); ! specIter.Done(); specIter.Next())
+    cFCOSpecListCanonicalIter specIter(mSpecList);
+    for (specIter.SeekBegin(); !specIter.Done(); specIter.Next())
     {
         mpCurSpec = specIter.Spec();
-    
+
         // verbose output
-        TW_NOTIFY_VERBOSE(  _T("%s%s\n"), 
-                            TSS_GetString( cTripwire, tripwire::STR_NOTIFY_CHECKING_RULE ).c_str(),
-                            iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay
-                                ( mpCurSpec->GetStartPoint() ).c_str() );
-        //  
+        TW_NOTIFY_VERBOSE(
+            _T("%s%s\n"),
+            TSS_GetString(cTripwire, tripwire::STR_NOTIFY_CHECKING_RULE).c_str(),
+            iTWFactory::GetInstance()->GetNameTranslator()->ToStringDisplay(mpCurSpec->GetStartPoint()).c_str());
+        //
         // add the spec to the report...
         //
         mReport.AddSpec(mGenre, mpCurSpec, specIter.Attr(), &mReportIter);
-        ASSERT(! mReportIter.Done());
+        ASSERT(!mReportIter.Done());
         //
         // associate the error bucket to this current spec in the report
         //
-        mReportIter.GetErrorQueue()->SetChild( mBucket.GetChild() );
-        mBucket.SetChild( mReportIter.GetErrorQueue() );
+        mReportIter.GetErrorQueue()->SetChild(mBucket.GetChild());
+        mBucket.SetChild(mReportIter.GetErrorQueue());
         //
         // seek each iterator to the appropriate starting point...
         //
-        dbIter.SeekToFCO    ( mpCurSpec->GetStartPoint(), false ); // false means not to create my peers
-        pDSIter->SeekToFCO  ( mpCurSpec->GetStartPoint(), false );
+        dbIter.SeekToFCO(mpCurSpec->GetStartPoint(), false); // false means not to create my peers
+        pDSIter->SeekToFCO(mpCurSpec->GetStartPoint(), false);
         //
         // integrity check the start point; note that the ProcessXXX functions will
         //      handle recursing into the subdirectories and stopping when the spec says to
         //
-        if( dbIter.Done() && pDSIter->Done() )
+        if (dbIter.Done() && pDSIter->Done())
         {
-            // nothing to do here... 
+            // nothing to do here...
             ;
         }
-        else if( pDSIter->Done() )
+        else if (pDSIter->Done())
         {
             // removed object...
-            ProcessRemovedFCO( dbIter, pDSIter.get() );
+            ProcessRemovedFCO(dbIter, pDSIter.get());
         }
-        else if( dbIter.Done() )
+        else if (dbIter.Done())
         {
             // added object...
-            ProcessAddedFCO( dbIter, pDSIter.get() );
+            ProcessAddedFCO(dbIter, pDSIter.get());
         }
         else
         {
             // possible changed fco
-            ProcessChangedFCO( dbIter, pDSIter.get() );
+            ProcessChangedFCO(dbIter, pDSIter.get());
         }
 
         // dissociate the report error bucket and mine...
         //
-        mBucket.SetChild( mReportIter.GetErrorQueue()->GetChild() );
-        mReportIter.GetErrorQueue()->SetChild( 0 );
+        mBucket.SetChild(mReportIter.GetErrorQueue()->GetChild());
+        mReportIter.GetErrorQueue()->SetChild(0);
     }
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // ExecuteOnObjectList
 ///////////////////////////////////////////////////////////////////////////////
-void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames, uint32 flags )
+void cIntegrityCheck::ExecuteOnObjectList(const std::list<cFCOName>& fcoNames, uint32 flags)
 {
     iFCONameTranslator* pTrans = iTWFactory::GetInstance()->GetNameTranslator();
     //
     // create the data source iterator
     //
-    std::auto_ptr<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
+    TW_UNIQUE_PTR<iFCODataSourceIter> pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
     //
     // set up the database's iterator...
     // I assume the current genre is correct...
     //
-    cDbDataSourceIter           dbIter  ( &mDb );   
-    cFCOSpecListCanonicalIter   specIter(mSpecList);
-    
+    cDbDataSourceIter         dbIter(&mDb);
+    cFCOSpecListCanonicalIter specIter(mSpecList);
+
     //
     // set the iterators' error bucket...
     //
@@ -568,37 +579,42 @@ void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames,
 
     //
     // set up flags for the property calculator and iterators
-    //    
-    if( flags & FLAG_ERASE_FOOTPRINTS_IC )
+    //
+    if (flags & FLAG_ERASE_FOOTPRINTS_IC)
     {
-        mpPropCalc->SetCalcFlags( iFCOPropCalc::DO_NOT_MODIFY_PROPERTIES );  
-        dbIter.SetIterFlags     ( iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS );
-        pDSIter->SetIterFlags   ( iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS );
+        mpPropCalc->SetCalcFlags(iFCOPropCalc::DO_NOT_MODIFY_PROPERTIES);
+        dbIter.SetIterFlags(iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS);
+        pDSIter->SetIterFlags(iFCODataSourceIter::DO_NOT_MODIFY_OBJECTS);
+    }
+
+    if (flags & FLAG_DIRECT_IO)
+    {
+        mpPropCalc->SetCalcFlags(mpPropCalc->GetCalcFlags() | iFCOPropCalc::DIRECT_IO);
     }
 
     //
     // iterate over all the objects to integrity check..
     //
     std::list<cFCOName>::const_iterator it;
-    for( it = fcoNames.begin(); it != fcoNames.end(); it++ )
+    for (it = fcoNames.begin(); it != fcoNames.end(); ++it)
     {
-        TW_NOTIFY_VERBOSE(  _T("%s%s\n"), 
-                            TSS_GetString( cTripwire, tripwire::STR_NOTIFY_CHECKING ).c_str(),
-                            pTrans->ToStringDisplay( *it ).c_str() );
+        TW_NOTIFY_VERBOSE(_T("%s%s\n"),
+                          TSS_GetString(cTripwire, tripwire::STR_NOTIFY_CHECKING).c_str(),
+                          pTrans->ToStringDisplay(*it).c_str());
         //
         // figure out which spec this fco belongs in...
         //
-        for( specIter.SeekBegin(); ! specIter.Done(); specIter.Next() )
+        for (specIter.SeekBegin(); !specIter.Done(); specIter.Next())
         {
-            if( specIter.Spec()->SpecContainsFCO( *it ) )
+            if (specIter.Spec()->SpecContainsFCO(*it))
                 break;
         }
         // error if we found no spec.
         //
-        if( specIter.Done() )
+        if (specIter.Done())
         {
-            mBucket.AddError                                ( eICFCONotInSpec( pTrans->ToStringDisplay( *it ) ) );
-            mReport.GetErrorQueue()->cErrorBucket::AddError ( eICFCONotInSpec( pTrans->ToStringDisplay( *it ) ) );
+            mBucket.AddError(eICFCONotInSpec(pTrans->ToStringDisplay(*it)));
+            mReport.GetErrorQueue()->cErrorBucket::AddError(eICFCONotInSpec(pTrans->ToStringDisplay(*it)));
             continue;
         }
         mpCurSpec = specIter.Spec();
@@ -606,23 +622,23 @@ void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames,
         // add this spec to the report if it is not there
         // and seek to the spec
         //
-        if( ! mReportIter.SeekToSpec( mpCurSpec ) )
+        if (!mReportIter.SeekToSpec(mpCurSpec))
         {
             mReport.AddSpec(mGenre, mpCurSpec, specIter.Attr(), &mReportIter);
         }
         // insert the report error bucket between mpErrorBucket and its children...
         //
-        mReportIter.GetErrorQueue()->SetChild( mBucket.GetChild() );
-        mBucket.SetChild( mReportIter.GetErrorQueue() );
+        mReportIter.GetErrorQueue()->SetChild(mBucket.GetChild());
+        mBucket.SetChild(mReportIter.GetErrorQueue());
         //
         // create the fco in the database...
         //
-        dbIter.SeekToFCO( *it, false );
-        if( dbIter.Done() || (! dbIter.HasFCOData()) )
+        dbIter.SeekToFCO(*it, false);
+        if (dbIter.Done() || (!dbIter.HasFCOData()))
         {
             // fco not found in the db!
             //
-            mBucket.AddError( eICFCONotInDb( pTrans->ToStringDisplay( *it ) ) );
+            mBucket.AddError(eICFCONotInDb(pTrans->ToStringDisplay(*it)));
         }
         else
         {
@@ -630,30 +646,28 @@ void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames,
             //
             // create the fco from the data source
             //
-            pDSIter->SeekToFCO  ( *it, false );
-            if( ! pDSIter->Done() )
+            pDSIter->SeekToFCO(*it, false);
+            if (!pDSIter->Done())
             {
                 iFCO* pNewFCO = pDSIter->CreateFCO();
-                mnObjectsScanned++;                    
-                mReportIter.SetObjectsScanned( mReportIter.GetObjectsScanned() + 1 );
-                    
-                if( pNewFCO )
+                mnObjectsScanned++;
+                mReportIter.SetObjectsScanned(mReportIter.GetObjectsScanned() + 1);
+
+                if (pNewFCO)
                 {
-                    CompareFCOs( pOldFCO, pNewFCO );
+                    CompareFCOs(pOldFCO, pNewFCO);
                     pNewFCO->Release();
                 }
                 else
                 {
-                    mBucket.AddError( eICFCOCreate( pTrans->ToStringDisplay( *it ) ) );
+                    mBucket.AddError(eICFCOCreate(pTrans->ToStringDisplay(*it)));
                 }
             }
             pOldFCO->Release();
         }
         // dissociate the report error bucket and mine...
         //
-        mBucket.SetChild( mReportIter.GetErrorQueue()->GetChild() );
-        mReportIter.GetErrorQueue()->SetChild( 0 );
+        mBucket.SetChild(mReportIter.GetErrorQueue()->GetChild());
+        mReportIter.GetErrorQueue()->SetChild(0);
     }
-    
 }
-
