@@ -1,31 +1,31 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2018 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
-// 
+//
 // This program is free software.  The contents of this file are subject
 // to the terms of the GNU General Public License as published by the
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version.  You may redistribute it and/or modify it
 // only in compliance with the GNU General Public License.
-// 
+//
 // This program is distributed in the hope that it will be useful.
 // However, this program is distributed AS-IS WITHOUT ANY
 // WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
 // FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
 // for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 // USA.
-// 
+//
 // Nothing in the GNU General Public License or any other license to use
 // the code or files shall permit you to use Tripwire's trademarks,
 // service marks, or other intellectual property without Tripwire's
 // prior written consent.
-// 
+//
 // If you have any questions, please contact Tripwire, Inc. at either
 // info@tripwire.org or www.tripwire.org.
 //
@@ -68,7 +68,7 @@
 //////////////////////////////////////////////////////////////////////////////////////////////////
 //
 //static void util_PrintFCO(const iFCO* pFCO, iFCOPropDisplayer * pPropDisplayer);
-static void util_InitBlockArray( cBlockRecordArray& block );
+static void util_InitBlockArray(cBlockRecordArray& block);
 //static void util_MapHierRoot( std::map< std::pair< int, int>, int > dbMap );
 
 //////////////////////////////////////////////////////////////////////////////////////////////////
@@ -76,20 +76,21 @@ static void util_InitBlockArray( cBlockRecordArray& block );
 //////////////////////////////////////////////////////////////////////////////////////////////////
 struct cDbDebug_i
 {
-    cDbDebug_i() {};
-    ~cDbDebug_i() {};
+    cDbDebug_i(){};
+    ~cDbDebug_i(){};
 
-    typedef std::map< std::pair<int,int>, int > hierDbMap;
+    typedef std::map<std::pair<int, int>, int> hierDbMap;
     // This is the data structure that we will use to match the information stored in a quantum database
     // with its hierarchical representation!  For now, it will hold the <int, int> tuples representing
     // valid offsets in each block (referenced by a block number).  The bool value will be set to false
-    // on the first run, and then flipped to true for each entry that is found while traversing the 
+    // on the first run, and then flipped to true for each entry that is found while traversing the
     // hierarchical database.
-    typedef std::list< std::pair< int, int> > AddressList;
+    typedef std::list<std::pair<int, int> > AddressList;
 
-    hierDbMap mDbMap;                       // The map itself.
-    AddressList mlMissingFromBlockFile;     // A list for keeping track of nodes found in the hierarchy, but not the blockfile
-    AddressList mlMissingFromHierarchy;     // The opposite case.
+    hierDbMap mDbMap; // The map itself.
+    AddressList
+                mlMissingFromBlockFile; // A list for keeping track of nodes found in the hierarchy, but not the blockfile
+    AddressList mlMissingFromHierarchy; // The opposite case.
 };
 
 cDbDebug::cDbDebug()
@@ -106,9 +107,9 @@ cDbDebug::~cDbDebug()
 ///////////////////////////////////////////////////////////////////////////////
 // util_InitBlockArray
 ///////////////////////////////////////////////////////////////////////////////
-static void util_InitBlockArray( cBlockRecordArray& block )
+static void util_InitBlockArray(cBlockRecordArray& block)
 {
-    if( ! block.Initialized() )
+    if (!block.Initialized())
     {
         block.InitForExistingBlock();
     }
@@ -117,18 +118,18 @@ static void util_InitBlockArray( cBlockRecordArray& block )
 ///////////////////////////////////////////////////////////////////////////////
 // util_MapHierRoot : Map the Root and RootArray in the HierDatabase:
 ///////////////////////////////////////////////////////////////////////////////
-static void util_MapHierRoot( std::map< std::pair< int, int>, int >* dbMap )
+static void util_MapHierRoot(std::map<std::pair<int, int>, int>* dbMap)
 {
-    cDbDebug_i::hierDbMap::iterator i = dbMap->find( std::pair<int, int> ( 0, 0 ) );
+    cDbDebug_i::hierDbMap::iterator i = dbMap->find(std::pair<int, int>(0, 0));
     //dbMap->insert( cDbDebug_i::hierDbMap::value_type( std::pair< int, int > ( 0, 0 ), 1 ) );
     //
     // This insert statement should work to change the value, but it doesn't ????
     (*i).second = 1;
 
-    i = dbMap->find( std::pair<int, int> ( 0, 1 ) );
+    i           = dbMap->find(std::pair<int, int>(0, 1));
     (*i).second = 1;
 
-    i = dbMap->find( std::pair<int, int> ( 0, 2 ) );
+    i           = dbMap->find(std::pair<int, int>(0, 2));
     (*i).second = 1;
 }
 
@@ -139,21 +140,22 @@ void cDbDebug::DisplayDbMap()
 {
     int loop_count = 0;
 
-    for(cDbDebug_i::hierDbMap::iterator i = cDbDebug::mpData->mDbMap.begin(); i!= cDbDebug::mpData->mDbMap.end(); ++i, ++loop_count)
+    for (cDbDebug_i::hierDbMap::iterator i = cDbDebug::mpData->mDbMap.begin(); i != cDbDebug::mpData->mDbMap.end();
+         ++i, ++loop_count)
     {
         TCOUT.width(6);
-        TCOUT<< (*i).first.first << _T(",") << (*i).first.second<<_T(" ");
-        TCOUT<<_T("(")<< (*i).second<<_T(")"); 
-        if( (loop_count % 5) == 0 )
-            TCOUT<< std::endl;
+        TCOUT << (*i).first.first << _T(",") << (*i).first.second << _T(" ");
+        TCOUT << _T("(") << (*i).second << _T(")");
+        if ((loop_count % 5) == 0)
+            TCOUT << std::endl;
     }
-    TCOUT<<std::endl;
+    TCOUT << std::endl;
 }
 
 /////////////////////////////////////////////////////////////////////////////////
 // GetHierDbMap() -- Returns a pointer to the map
 /////////////////////////////////////////////////////////////////////////////////
-cDbDebug::hierDbMap* cDbDebug::GetHierDbMap( void )
+cDbDebug::hierDbMap* cDbDebug::GetHierDbMap(void)
 {
     return &(mpData->mDbMap);
 }
@@ -162,30 +164,30 @@ cDbDebug::hierDbMap* cDbDebug::GetHierDbMap( void )
 // Execute :
 //      Drives the DebugDb mode of tripwire, which will only be used for internal use.
 //////////////////////////////////////////////////////////////////////////////////////////////////////
-void cDbDebug::Execute( cFCODatabaseFileIter& dbIter, const TSTRING& dbFile )
+void cDbDebug::Execute(cFCODatabaseFileIter& dbIter, const TSTRING& dbFile)
 {
-    
-    cDebug d("cDebugDb::Execute");
+
+    cDebug   d("cDebugDb::Execute");
     cDbDebug DbDebug;
     //
     //A derived class with extra methods for obtaining blockfile information.
     cDebugHierDb* db;
     //
     // Cast the database object that we have inherited from the "common" command line
-    // information to a cDebugHierDb.  This will expose all the information that we 
+    // information to a cDebugHierDb.  This will expose all the information that we
     // need to debug the database.
     //
     db = static_cast<cDebugHierDb*>(&(dbIter.GetDb()));
 
     try
     {
-        cDebugHierDbIter pIter( db );
+        cDebugHierDbIter pIter(db);
 
         //
-        //First, map the state of the underlying quantyum database.  Store this info. in 
+        //First, map the state of the underlying quantyum database.  Store this info. in
         //the hierDbMap.
         //
-        DbDebug.MapQuantumDatabase( *db );
+        DbDebug.MapQuantumDatabase(*db);
 
         //DbDebug.DisplayDbMap(); //TODO : get rid of these display calls.
 
@@ -196,14 +198,14 @@ void cDbDebug::Execute( cFCODatabaseFileIter& dbIter, const TSTRING& dbFile )
 
         // Next, traverse the hierarchical overlay and "tag" all entries in the map that
         // we see:
-        ASSERT( pIter.AtRoot() );
-            //
-            // check to make sure we are at the root of the hierarchy, if so, map the root
-            // before calling the recursive traversal function.
-            //
-        util_MapHierRoot( DbDebug.GetHierDbMap() );
+        ASSERT(pIter.AtRoot());
+        //
+        // check to make sure we are at the root of the hierarchy, if so, map the root
+        // before calling the recursive traversal function.
+        //
+        util_MapHierRoot(DbDebug.GetHierDbMap());
 
-        DbDebug.TraverseHierarchy( pIter /*, db*/ );
+        DbDebug.TraverseHierarchy(pIter /*, db*/);
 
         //DbDebug.DisplayDbMap(); //TODO: get rid of these display calls.
         //
@@ -216,13 +218,12 @@ void cDbDebug::Execute( cFCODatabaseFileIter& dbIter, const TSTRING& dbFile )
         //
         DbDebug.OutputResults();
 
-    }//try
+    } //try
 
-    catch( eError& e )
+    catch (eError& e)
     {
-        cErrorReporter::PrintErrorMsg( e );
+        cErrorReporter::PrintErrorMsg(e);
     }
-    
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -235,14 +236,14 @@ void cDbDebug::Execute( cFCODatabaseFileIter& dbIter, const TSTRING& dbFile )
 // Addition: 2/15/99: We want to print out statistics on the current state of the block
 //  file, so let's do it here ( since we're traversing it to map the addresses, anyway ).
 //////////////////////////////////////////////////////////////////////////////////////////////
-void cDbDebug::MapQuantumDatabase( cDebugHierDb& db )
+void cDbDebug::MapQuantumDatabase(cDebugHierDb& db)
 {
     //mirroring the implementation in blockrecordfile.h:
-    typedef std::vector<cBlockRecordArray>  BlockArray;
+    typedef std::vector<cBlockRecordArray> BlockArray;
 
     //Using the two added methods to gain access to the low-level implementation of the
     //quantum database.
-    BlockArray* pBlkArray =     db.myGetBlockArray();
+    BlockArray* pBlkArray = db.myGetBlockArray();
 
     // Print some statistics on the blockfile if we're in debug mode:
 #ifdef _BLOCKFILE_DEBUG
@@ -252,12 +253,12 @@ void cDbDebug::MapQuantumDatabase( cDebugHierDb& db )
     // assessed.
 
     // time to iterate over the database:
-    std::vector< cBlockRecordArray >::iterator i;
-    int count = 0;
+    std::vector<cBlockRecordArray>::iterator i;
+    int                                      count = 0;
 
-    for( i = (*pBlkArray).begin(); i != (*pBlkArray).end(); ++i, ++count )
+    for (i = (*pBlkArray).begin(); i != (*pBlkArray).end(); ++i, ++count)
     {
-        util_InitBlockArray( *i );
+        util_InitBlockArray(*i);
         //This is necessary to make sure that each block is initialized as we iterate
         //over the block array.
         //
@@ -270,18 +271,18 @@ void cDbDebug::MapQuantumDatabase( cDebugHierDb& db )
         //Search through all the indexes and determine which of them references valid
         //information.  Store these <int, int> pairs ( the first int being the value of
         //count....
-        for( int j = 0; j <= i->GetNumItems(); ++j )
+        for (int j = 0; j <= i->GetNumItems(); ++j)
         {
-            if( i->IsItemValid( j ) )
+            if (i->IsItemValid(j))
             {
                 //
                 // We found a valid node in the database, so store it in the map.
                 //
-                mpData->mDbMap.insert( cDbDebug_i::hierDbMap::value_type( std::pair<int, int> (count, j) , 0 ));
+                mpData->mDbMap.insert(cDbDebug_i::hierDbMap::value_type(std::pair<int, int>(count, j), 0));
             }
             // if not, just don't store it.  The index is no longer valid.
         }
-    }   
+    }
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -291,9 +292,9 @@ void cDbDebug::MapQuantumDatabase( cDebugHierDb& db )
 // structures that make up the object.  Looks at data addresses as well as structures that are
 // necessary to maintain the hierarchy ( namely cHierArrayInfo records ).
 ////////////////////////////////////////////////////////////////////////////////////////////////
-void cDbDebug::TraverseHierarchy( cDebugHierDbIter pIter)
+void cDbDebug::TraverseHierarchy(cDebugHierDbIter pIter)
 {
-    if( ! pIter.CanDescend() )
+    if (!pIter.CanDescend())
         return; //Done with this call.
 
     pIter.Descend();
@@ -301,59 +302,73 @@ void cDbDebug::TraverseHierarchy( cDebugHierDbIter pIter)
     //Descend once from the root, into the first child set. Also, descend once for each recursive call.
     //
 
-    for( pIter.SeekBegin(); !pIter.Done(); pIter.Next() )
+    for (pIter.SeekBegin(); !pIter.Done(); pIter.Next())
     {
-            //Try to match the parent's address in the database.
-            if( !pIter.Done() )
+        //Try to match the parent's address in the database.
+        if (!pIter.Done())
+        {
+            if (pIter.myGetEntryArrayIt() == pIter.myGetEntryArray().begin())
+            //We're dealing with a cHierArrayInfo object, so treat it differently.
+            {
+                //
+                // Let's map the parent address, and the array address, so we account for all the data structures
+                // that make up this particular node.
+                //
+                MapHierDbNodes(mpData->mDbMap,
+                               std::pair<int, int>(pIter.myGetArrayInfo().mParent.mBlockNum,
+                                                   pIter.myGetArrayInfo().mParent.mIndex),
+                               pIter);
+                // and the array...
+                MapHierDbNodes(
+                    mpData->mDbMap,
+                    std::pair<int, int>(pIter.myGetArrayInfo().mArray.mBlockNum, pIter.myGetArrayInfo().mArray.mIndex),
+                    pIter);
+            }
+            else
+            //This is a regular cHierEntry, so look at the Data and Child (if it exists ).
             {
-                if( pIter.myGetEntryArrayIt() == pIter.myGetEntryArray().begin() )
-                    //We're dealing with a cHierArrayInfo object, so treat it differently.
-                {
-                    //
-                    // Let's map the parent address, and the array address, so we account for all the data structures 
-                    // that make up this particular node.
-                    //
-                    MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(pIter.myGetArrayInfo().mParent.mBlockNum, pIter.myGetArrayInfo().mParent.mIndex), pIter );
-                    // and the array...
-                    MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(pIter.myGetArrayInfo().mArray.mBlockNum, pIter.myGetArrayInfo().mArray.mIndex), pIter );
-                }
-                else
-                    //This is a regular cHierEntry, so look at the Data and Child (if it exists ).
-                {
 
-                    cDebugHierDbIter::EntryArray::iterator lEntryArrayIt = pIter.myGetEntryArrayIt();
+                cDebugHierDbIter::EntryArray::iterator lEntryArrayIt = pIter.myGetEntryArrayIt();
 
-                    MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(lEntryArrayIt->mData.mBlockNum, lEntryArrayIt->mData.mIndex), pIter );
+                MapHierDbNodes(mpData->mDbMap,
+                               std::pair<int, int>(lEntryArrayIt->mData.mBlockNum, lEntryArrayIt->mData.mIndex),
+                               pIter);
 
-                    --lEntryArrayIt;
-                    // Get the address of this node by examining the previous next pointer in the entry list.
-                    //
+                --lEntryArrayIt;
+                // Get the address of this node by examining the previous next pointer in the entry list.
+                //
 
-                    //
-                    // Map the next peer entry in the list. TODO: This may very well be overkill... if so, lose this call to MapHierDbNodes.
-                    //
-                    MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(lEntryArrayIt->mNext.mBlockNum, lEntryArrayIt->mNext.mIndex), pIter );
-                    //
-                    // We also want to map the address of the child array, if non-null.
-                    //
-                    if( lEntryArrayIt->mChild.mBlockNum != -1 )
-                        MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(lEntryArrayIt->mChild.mBlockNum, lEntryArrayIt->mChild.mIndex), pIter );
-                    //
-                    // Finally, map the address of the data.
-                    //
-                    MapHierDbNodes( mpData->mDbMap, std::pair<int,int>(lEntryArrayIt->mData.mBlockNum, lEntryArrayIt->mData.mIndex), pIter );
-                }
+                //
+                // Map the next peer entry in the list. TODO: This may very well be overkill... if so, lose this call to MapHierDbNodes.
+                //
+                MapHierDbNodes(mpData->mDbMap,
+                               std::pair<int, int>(lEntryArrayIt->mNext.mBlockNum, lEntryArrayIt->mNext.mIndex),
+                               pIter);
+                //
+                // We also want to map the address of the child array, if non-null.
+                //
+                if (lEntryArrayIt->mChild.mBlockNum != -1)
+                    MapHierDbNodes(mpData->mDbMap,
+                                   std::pair<int, int>(lEntryArrayIt->mChild.mBlockNum, lEntryArrayIt->mChild.mIndex),
+                                   pIter);
+                //
+                // Finally, map the address of the data.
+                //
+                MapHierDbNodes(mpData->mDbMap,
+                               std::pair<int, int>(lEntryArrayIt->mData.mBlockNum, lEntryArrayIt->mData.mIndex),
+                               pIter);
+            }
 
-            }//if
+        } //if
         //
         // Check to see if this particular node has a child array. If so, make recursive call.
         //
-        if( pIter.CanDescend() ) 
+        if (pIter.CanDescend())
         {
             //This node has children, call myself
-            TraverseHierarchy( pIter );
+            TraverseHierarchy(pIter);
         }
-    }//for
+    } //for
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -362,17 +377,19 @@ void cDbDebug::TraverseHierarchy( cDebugHierDbIter pIter)
 // Maps a given address in the hierarchy.  This function looks up the address in the map and flips an integer flag
 // to record the event.  If the address is not found, it is placed in a list of addresses for error output.
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-void cDbDebug::MapHierDbNodes( std::map< std::pair< int, int > , int >& dbMap, std::pair<int, int> address, cDebugHierDbIter& pIter )
+void cDbDebug::MapHierDbNodes(std::map<std::pair<int, int>, int>& dbMap,
+                              std::pair<int, int>                 address,
+                              cDebugHierDbIter&                   pIter)
 {
-    cDbDebug_i::hierDbMap::iterator i = dbMap.find( std::pair< int, int> (address.first, address.second) );
+    cDbDebug_i::hierDbMap::iterator i = dbMap.find(std::pair<int, int>(address.first, address.second));
 
-    if( i != dbMap.end() )
+    if (i != dbMap.end())
     {
         (*i).second = 1;
         //Flip the integer flag to 1, since we've found the address in the hierarchy.
     }
     else
-        mpData->mlMissingFromBlockFile.push_back( std::pair<int, int> (address.first, address.second));
+        mpData->mlMissingFromBlockFile.push_back(std::pair<int, int>(address.first, address.second));
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -382,18 +399,18 @@ void cDbDebug::MapHierDbNodes( std::map< std::pair< int, int > , int >& dbMap, s
 // hierarchy traversal.  If there are, push the offending addresses onto the address list.
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-void cDbDebug::CongruencyTest( void )
+void cDbDebug::CongruencyTest(void)
 {
     cDbDebug_i::hierDbMap::iterator i = mpData->mDbMap.begin();
-    for( ; i != mpData->mDbMap.end(); ++i )
+    for (; i != mpData->mDbMap.end(); ++i)
     {
-        if ( (*i).second != 1 )
+        if ((*i).second != 1)
         {
-            //We've found something in the blockfile map that is not accounted for by the 
+            //We've found something in the blockfile map that is not accounted for by the
             //hierarchy.  Add this address to the appropriate list.
             //TCOUT<< (*i).first.first << _T(",") << (*i).first.second << std::endl;
             //TCOUT<< (*i).second <<std::endl;
-            mpData->mlMissingFromHierarchy.push_back( std::pair< int, int> ( (*i).first.first, (*i).first.second ) );
+            mpData->mlMissingFromHierarchy.push_back(std::pair<int, int>((*i).first.first, (*i).first.second));
         }
     }
 }
@@ -402,47 +419,47 @@ void cDbDebug::CongruencyTest( void )
 // OutputResults --
 //
 // Output the results of the congruency test.  Print information contained in the two
-// "error lists" if they have entries. 
+// "error lists" if they have entries.
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-void cDbDebug::OutputResults( void )
+void cDbDebug::OutputResults(void)
 {
-    TCOUT<< _T("\nResults of Blockfile / Hierarchy congruency tests: \n") << std::endl;
-    
+    TCOUT << _T("\nResults of Blockfile / Hierarchy congruency tests: \n") << std::endl;
+
     // Check to see if our error lists are empty.  If so, output a message that indicates
-    // that the two databases checked clean. 
-    if( mpData->mlMissingFromHierarchy.empty() && mpData->mlMissingFromBlockFile.empty() )
-        TCOUT<< _T("The database representations match!\n") << std::endl;
+    // that the two databases checked clean.
+    if (mpData->mlMissingFromHierarchy.empty() && mpData->mlMissingFromBlockFile.empty())
+        TCOUT << _T("The database representations match!\n") << std::endl;
     else
     {
         // Check to see if there was anything in the hierarchy that was not accounted for by the
         // blockfile (quantum database).
-        if( !mpData->mlMissingFromBlockFile.empty() )
+        if (!mpData->mlMissingFromBlockFile.empty())
         {
-            TCOUT<< _T(" Objects (referenced by address) found in the hierarchy that were not\n");
-            TCOUT<< _T(" accounted for by the underlying quantum database: \n");
+            TCOUT << _T(" Objects (referenced by address) found in the hierarchy that were not\n");
+            TCOUT << _T(" accounted for by the underlying quantum database: \n");
 
             cDbDebug_i::AddressList::iterator i = mpData->mlMissingFromBlockFile.begin();
-            for( ; i != mpData->mlMissingFromBlockFile.end(); ++i )
+            for (; i != mpData->mlMissingFromBlockFile.end(); ++i)
                 TCOUT << _T("(") << (*i).first << _T(",") << (*i).second << _T(")") << std::endl;
         }
         else
-            TCOUT<< _T(" All objects in Blockfile accounted for!\n");
+            TCOUT << _T(" All objects in Blockfile accounted for!\n");
 
-        //check to see if there was anything in the blockfile that was not accounted for by the 
+        //check to see if there was anything in the blockfile that was not accounted for by the
         // hierarchy:
-        if ( !mpData->mlMissingFromHierarchy.empty() )
+        if (!mpData->mlMissingFromHierarchy.empty())
         {
-            TCOUT<< _T(" Database information (referenced by a <blocknumber, offset> address)\n");
-            TCOUT<< _T(" not accounted for by the hierarchy :\n");
+            TCOUT << _T(" Database information (referenced by a <blocknumber, offset> address)\n");
+            TCOUT << _T(" not accounted for by the hierarchy :\n");
 
             cDbDebug_i::AddressList::iterator i = mpData->mlMissingFromHierarchy.begin();
-            for( ; i != mpData->mlMissingFromHierarchy.end(); ++i )
+            for (; i != mpData->mlMissingFromHierarchy.end(); ++i)
                 TCOUT << _T("(") << (*i).first << _T(",") << (*i).second << _T(")") << std::endl;
         }
         else
-            TCOUT<<_T("All objects in Hierarchy accounted for!\n");
-    }//else
+            TCOUT << _T("All objects in Hierarchy accounted for!\n");
+    } //else
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -450,6 +467,7 @@ void cDbDebug::OutputResults( void )
 // Begin code for manipulating Database -- This is just a straight port from the DbExplore code.  It's presence is
 // purely for convenience, and for debugging this class.
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+/*
 static inline bool IsSpace( TCHAR c )
 {
     return ( (c == _T(' ')) || (c == _T('\t')) || (c == _T('\r')) || (c == _T('\n')) || (c == _T('\0')) );
@@ -460,7 +478,6 @@ static inline bool IsEnd( TCHAR c )
     return ( (c == _T('\0')) );
 }
 
-/*
 ///////////////////////////////////////////////////////////////////////////////
 // util_PrintFCO
 ///////////////////////////////////////////////////////////////////////////////
