@@ -1,31 +1,31 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2018 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
-// 
+//
 // This program is free software.  The contents of this file are subject
 // to the terms of the GNU General Public License as published by the
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version.  You may redistribute it and/or modify it
 // only in compliance with the GNU General Public License.
-// 
+//
 // This program is distributed in the hope that it will be useful.
 // However, this program is distributed AS-IS WITHOUT ANY
 // WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
 // FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
 // for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 // USA.
-// 
+//
 // Nothing in the GNU General Public License or any other license to use
 // the code or files shall permit you to use Tripwire's trademarks,
 // service marks, or other intellectual property without Tripwire's
 // prior written consent.
-// 
+//
 // If you have any questions, please contact Tripwire, Inc. at either
 // info@tripwire.org or www.tripwire.org.
 //
@@ -43,7 +43,7 @@
 //#include "cryptlib/queue.h"
 #include "bytequeue.h"
 
-enum mAction 
+enum mAction
 {
     MA_UNSTARTED,
     MA_UNKNOWN,
@@ -58,7 +58,7 @@ const int CRYPTO_COMPRESSION_LEVEL = 6;
 // folowing interfaces were added to use Crypto++'s implementation
 // of gzip
 
-// class that takes a plaintext input via Put() and 
+// class that takes a plaintext input via Put() and
 // outputs encrypted data to the passed in cArchive
 class cCryptoSink : public Sink
 {
@@ -66,57 +66,63 @@ public:
     cCryptoSink(cArchive* pDestArchive, iCipher* pCipher);
     ~cCryptoSink();
 
-    virtual void Put(const byte *inString, unsigned int length);
+    virtual void Put(const byte* inString, unsigned int length);
     virtual void InputFinished();
 
-    virtual void Put(byte inByte) { Put(&inByte, 1); }
+    virtual void Put(byte inByte)
+    {
+        Put(&inByte, 1);
+    }
 
 private:
-    cArchive*   mpDestArchive;
-    iCipher*    mpCipher;
+    cArchive* mpDestArchive;
+    iCipher*  mpCipher;
 
     // buffer to cache bytes in
-    int8*       mpBuffer;
-    int         mBufferLen;
-    int         mBufferUsed;
+    int8* mpBuffer;
+    int   mBufferLen;
+    int   mBufferUsed;
 };
 
 class cCryptoSource : public Source
 {
 public:
-    cCryptoSource(cArchive* pSrcArchive, iCipher* pCipher, BufferedTransformation *outQueue);
+    cCryptoSource(cArchive* pSrcArchive, iCipher* pCipher, BufferedTransformation* outQueue);
     ~cCryptoSource();
 
-    unsigned int Pump(unsigned int size);
+    unsigned int  Pump(unsigned int size);
     unsigned long PumpAll();
 
 private:
-    cArchive*   mpSrcArchive;
-    iCipher*    mpCipher;
+    cArchive* mpSrcArchive;
+    iCipher*  mpCipher;
 
     // buffer to cache bytes in
-    int8*       mpBuffer;
-    int         mBufferLen;
-    int         mBufferUsed;
+    int8* mpBuffer;
+    int   mBufferLen;
+    int   mBufferUsed;
 };
 
 cCryptoArchive::cCryptoArchive()
 {
-    mpArchive = 0;
-    mpCipher = 0;
-    mpDeflator = 0;
-    mpInflator = 0;
-    mpCryptoSink = 0;
-    mpCryptoSource = 0;
+    mpArchive       = 0;
+    mpCipher        = 0;
+    mpDeflator      = 0;
+    mpInflator      = 0;
+    mpCryptoSink    = 0;
+    mpCryptoSource  = 0;
     mpInflatedBytes = 0;
-    mAction = MA_UNSTARTED;
+    mAction         = MA_UNSTARTED;
 }
 
 cCryptoArchive::~cCryptoArchive()
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_UNKNOWN || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
-    
+    // check we did not leave a buffer unwritten
+
+    Finish();
+
+    // Finish() normally zeroes these out, but hey.
     delete mpDeflator;
     delete mpInflator;
 }
@@ -124,10 +130,10 @@ cCryptoArchive::~cCryptoArchive()
 void cCryptoArchive::Start(cArchive* pArchive, iCipher* pCipher)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_UNKNOWN || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
-    
+    // check we did not leave a buffer unwritten
+
     mpArchive = pArchive;
-    mpCipher = pCipher;
+    mpCipher  = pCipher;
 
     delete mpDeflator;
     mpDeflator = 0;
@@ -157,7 +163,7 @@ int cCryptoArchive::Write(const void* pSrc, int count)
         ASSERT(mpInflatedBytes == 0);
 
         mpCryptoSink = new cCryptoSink(mpArchive, mpCipher);
-        mpDeflator = new Deflator(CRYPTO_COMPRESSION_LEVEL, mpCryptoSink);
+        mpDeflator   = new Deflator(CRYPTO_COMPRESSION_LEVEL, mpCryptoSink);
     }
     else if (mAction != MA_WRITING)
     {
@@ -184,10 +190,10 @@ int cCryptoArchive::Read(void* pDest, int count)
         ASSERT(mpInflator == 0);
         ASSERT(mpCryptoSource == 0);
         ASSERT(mpInflatedBytes == 0);
-        
+
         mpInflatedBytes = new cByteQueue;
-        mpInflator = new Inflator(mpInflatedBytes);
-        mpCryptoSource = new cCryptoSource(mpArchive, mpCipher, mpInflator);
+        mpInflator      = new Inflator(mpInflatedBytes);
+        mpCryptoSource  = new cCryptoSource(mpArchive, mpCipher, mpInflator);
     }
     else if (mAction != MA_READING)
     {
@@ -195,13 +201,13 @@ int cCryptoArchive::Read(void* pDest, int count)
         throw eArchiveInvalidOp();
     }
 
-    while ( (int)mpInflatedBytes->CurrentSize() < count )
+    while ((int)mpInflatedBytes->CurrentSize() < count)
     {
         len = mpCipher->GetBlockSizePlain();
-        if ( (int)mpCryptoSource->Pump(len) < len )             // RAD: Cast to int
+        if ((int)mpCryptoSource->Pump(len) < len) // RAD: Cast to int
         {
             mpInflator->InputFinished();
-            if ( (int)mpInflatedBytes->CurrentSize() < count )  // RAD: Cast to int
+            if ((int)mpInflatedBytes->CurrentSize() < count) // RAD: Cast to int
             {
                 len = mpInflatedBytes->CurrentSize();
                 mpInflatedBytes->Get((byte*)pDest, len);
@@ -218,7 +224,7 @@ int cCryptoArchive::Read(void* pDest, int count)
 
 bool cCryptoArchive::EndOfFile()
 {
-    ASSERT(mAction == MA_READING);  // why would you call this if not reading?
+    ASSERT(mAction == MA_READING); // why would you call this if not reading?
     if (mAction != MA_READING)
         return true;
 
@@ -238,7 +244,7 @@ void cCryptoArchive::Finish()
         mpDeflator->InputFinished();
         mpCryptoSink->InputFinished();
         delete mpDeflator;
-        mpDeflator = 0;
+        mpDeflator   = 0;
         mpCryptoSink = 0; // mpCryptoSink is deleted by ~Deflator()
 
         mAction = MA_FINISHED;
@@ -247,7 +253,7 @@ void cCryptoArchive::Finish()
     {
         delete mpCryptoSource;
         mpCryptoSource = 0;
-        mpInflator = 0;  // deleting mpCryptoSource is deleted by ~Inflator()
+        mpInflator     = 0; // deleting mpCryptoSource is deleted by ~Inflator()
 
         mAction = MA_FINISHED;
     }
@@ -261,10 +267,10 @@ void cCryptoArchive::Finish()
 cCryptoSink::cCryptoSink(cArchive* pDestArchive, iCipher* pCipher)
 {
     mpDestArchive = pDestArchive;
-    mpCipher = pCipher;
-    mpBuffer = 0;
-    mBufferLen = 0;
-    mBufferUsed = 0;
+    mpCipher      = pCipher;
+    mpBuffer      = 0;
+    mBufferLen    = 0;
+    mBufferUsed   = 0;
 }
 
 cCryptoSink::~cCryptoSink()
@@ -272,22 +278,22 @@ cCryptoSink::~cCryptoSink()
     delete [] mpBuffer;
 }
 
-void cCryptoSink::Put(const byte *inString, unsigned int length)
+void cCryptoSink::Put(const byte* inString, unsigned int length)
 {
     if (mpBuffer == 0)
     {
         // this is the first write
-        mBufferLen = mpCipher->GetBlockSizePlain();
-        mpBuffer = new int8[mBufferLen];
+        mBufferLen  = mpCipher->GetBlockSizePlain();
+        mpBuffer    = new int8[mBufferLen];
         mBufferUsed = 0;
     }
 
     // RAD: Cast to int
-    ASSERT( length <= std::numeric_limits<unsigned int>::max() );
-    int nLength = static_cast<int>( length );
+    ASSERT(length <= std::numeric_limits<unsigned int>::max());
+    int nLength = static_cast<int>(length);
 
     int i = 0;
-    while ( i < nLength )               
+    while (i < nLength)
     {
         int bytesToCopy = mBufferLen - mBufferUsed;
         if (bytesToCopy > nLength - i)
@@ -312,7 +318,7 @@ void cCryptoSink::Put(const byte *inString, unsigned int length)
         i += bytesToCopy;
     }
 
-    ASSERT( i == nLength ); // should be if our math is right
+    ASSERT(i == nLength); // should be if our math is right
 }
 
 void cCryptoSink::InputFinished()
@@ -331,21 +337,21 @@ void cCryptoSink::InputFinished()
         mBufferUsed = 0;
     }
 
-    delete  [] mpBuffer;
-    mpBuffer = 0;
-    mBufferLen = 0;
+    delete [] mpBuffer;
+    mpBuffer    = 0;
+    mBufferLen  = 0;
     mBufferUsed = 0;
 }
 
 
-cCryptoSource::cCryptoSource(cArchive* pSrcArchive, iCipher* pCipher, BufferedTransformation *outQueue)
-:   Source(outQueue)
+cCryptoSource::cCryptoSource(cArchive* pSrcArchive, iCipher* pCipher, BufferedTransformation* outQueue)
+    : Source(outQueue)
 {
     mpSrcArchive = pSrcArchive;
-    mpCipher = pCipher;
+    mpCipher     = pCipher;
 
-    mpBuffer = 0;
-    mBufferLen = 0;
+    mpBuffer    = 0;
+    mBufferLen  = 0;
     mBufferUsed = 0;
 }
 
@@ -359,32 +365,32 @@ unsigned int cCryptoSource::Pump(unsigned int size)
     if (mpBuffer == 0)
     {
         // first time this has been called
-        mBufferLen = mpCipher->GetBlockSizePlain();
-        mpBuffer = new int8[mBufferLen];
+        mBufferLen  = mpCipher->GetBlockSizePlain();
+        mpBuffer    = new int8[mBufferLen];
         mBufferUsed = mBufferLen;
     }
 
     // RAD: Cast to int (Why are these locals signed if the interface is unsigned?)
-    ASSERT( size <= std::numeric_limits<unsigned int>::max() );
-    int nSize = static_cast<int>( size );
+    ASSERT(size <= std::numeric_limits<unsigned int>::max());
+    int nSize = static_cast<int>(size);
 
     int i = 0;
-    while ( i < nSize )
+    while (i < nSize)
     {
         if (mBufferUsed >= mBufferLen)
         {
-            ASSERT( mBufferUsed == mBufferLen ); // should be if our math is right
+            ASSERT(mBufferUsed == mBufferLen); // should be if our math is right
 
             int8* pTmp = new int8[mpCipher->GetBlockSizeCipher()];
 
-            int l = mpSrcArchive->ReadBlob( pTmp, mpCipher->GetBlockSizeCipher() );
-            if ( l != mpCipher->GetBlockSizeCipher() )
+            int l = mpSrcArchive->ReadBlob(pTmp, mpCipher->GetBlockSizeCipher());
+            if (l != mpCipher->GetBlockSizeCipher())
             {
                 delete [] pTmp;
                 return 0;
             }
 
-            mpCipher->ProcessBlock( pTmp, mpBuffer );
+            mpCipher->ProcessBlock(pTmp, mpBuffer);
 
             delete [] pTmp;
             mBufferUsed = 0;
@@ -394,33 +400,33 @@ unsigned int cCryptoSource::Pump(unsigned int size)
         if (bytesToCopy > nSize - i)
             bytesToCopy = nSize - i;
 
-        outQueue->Put( (byte*)(mpBuffer + mBufferUsed), bytesToCopy );
+        outQueue->Put((byte*)(mpBuffer + mBufferUsed), bytesToCopy);
 
         mBufferUsed += bytesToCopy;
         i += bytesToCopy;
     }
 
-    ASSERT( i == nSize ); // should be if our math is right
+    ASSERT(i == nSize); // should be if our math is right
 
     return i;
 }
 
 unsigned long cCryptoSource::PumpAll()
 {
-    unsigned long total=0;
-    unsigned int l;
+    unsigned long total = 0;
+    unsigned int  l;
 
     if (mBufferLen == 0)
         mBufferLen = mpCipher->GetBlockSizePlain();
 
-    while ((l=Pump(mBufferLen)) != 0)
+    while ((l = Pump(mBufferLen)) != 0)
         total += l;
 
     return total;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// class cNullCryptoArchive 
+// class cNullCryptoArchive
 //
 // Works like crypto archive but uses no encryption. However, the compression
 // functionality of cCryptoArchive is still utilized.
@@ -437,13 +443,13 @@ cNullCryptoArchive::~cNullCryptoArchive()
 }
 
 void cNullCryptoArchive::Start(cArchive* pArchive)
-{ 
-    mCryptoArchive.Start(pArchive, mpNullCipher); 
+{
+    mCryptoArchive.Start(pArchive, mpNullCipher);
 }
 
 void cNullCryptoArchive::Finish()
-{ 
-    mCryptoArchive.Finish(); 
+{
+    mCryptoArchive.Finish();
 }
 
 bool cNullCryptoArchive::EndOfFile()
@@ -464,46 +470,40 @@ int cNullCryptoArchive::Write(const void* pSrc, int count)
 
 #ifdef _RSA_ENCRYPTION
 ///////////////////////////////////////////////////////////////////////////////
-// class cRSAArchive 
+// class cRSAArchive
 
-    cCryptoArchive  mCryptoArchive;
+cCryptoArchive mCryptoArchive;
 
-    int             mAction;
+int mAction;
 
-    cArchive*       mpArchive;
-    cRSAPublicKey*  mpPublicKey;
-    cRSAPrivateKey* mpPrivateKey;
-    
-cRSAArchive::cRSAArchive()
+cArchive*       mpArchive;
+cRSAPublicKey*  mpPublicKey;
+cRSAPrivateKey* mpPrivateKey;
+
+cRSAArchive::cRSAArchive() : mAction(MA_UNSTARTED), mpArchive(0), mpPublicKey(0), mpPrivaeKey(0), mpIDEA(new cIDEA)
 {
-    mAction = MA_UNSTARTED;
-    mpArchive = 0;
-    mpPublicKey = 0;
-    mpPrivateKey = 0;
-
-    mpIDEA = new cIDEA;
 }
 
 cRSAArchive::~cRSAArchive()
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
     delete mpIDEA;
 }
 
 void cRSAArchive::SetWrite(cArchive* pDestArchive, const cRSAPublicKey* pPublicKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_WRITING;
-    mpArchive = pDestArchive;
-    mpPublicKey = pPublicKey;
+    mAction      = MA_WRITING;
+    mpArchive    = pDestArchive;
+    mpPublicKey  = pPublicKey;
     mpPrivateKey = 0;
 
     // Create a random number and encode using public key
     cRSA  rsa(*mpPublicKey);
-    int8* key = new int8[rsa.GetBlockSizePlain()];
+    int8* key          = new int8[rsa.GetBlockSizePlain()];
     int8* encryptedKey = new int8[rsa.GetBlockSizeCipher()];
 
     RandomizeBytes(key, rsa.GetBlockSizePlain());
@@ -526,16 +526,16 @@ void cRSAArchive::SetWrite(cArchive* pDestArchive, const cRSAPublicKey* pPublicK
 void cRSAArchive::SetWrite(cArchive* pDestArchive, const cRSAPrivateKey* pPrivateKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_WRITING;
-    mpArchive = pDestArchive;
+    mAction      = MA_WRITING;
+    mpArchive    = pDestArchive;
     mpPrivateKey = pPrivateKey;
-    mpPublicKey = 0;
+    mpPublicKey  = 0;
 
     // Create a random number and encode using public key
     cRSA  rsa(*mpPrivateKey);
-    int8* key = new int8[rsa.GetBlockSizePlain()];
+    int8* key          = new int8[rsa.GetBlockSizePlain()];
     int8* encryptedKey = new int8[rsa.GetBlockSizeCipher()];
 
     RandomizeBytes(key, rsa.GetBlockSizePlain());
@@ -570,21 +570,21 @@ void cRSAArchive::FlushWrite()
 void cRSAArchive::SetRead(cArchive* pSrcArchive, const cRSAPublicKey* pPublicKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_READING;
-    mpArchive = pSrcArchive;
-    mpPublicKey = pPublicKey;
+    mAction      = MA_READING;
+    mpArchive    = pSrcArchive;
+    mpPublicKey  = pPublicKey;
     mpPrivateKey = 0;
 
     cRSA  rsa(*mpPublicKey);
-    int8* key = new int8[rsa.GetBlockSizePlain()];
+    int8* key          = new int8[rsa.GetBlockSizePlain()];
     int8* encryptedKey = new int8[rsa.GetBlockSizeCipher()];
 
     mpArchive->ReadBlob(encryptedKey, rsa.GetBlockSizeCipher());
     rsa.SetVerifying(mpPublicKey);
     rsa.ProcessBlock(encryptedKey, key);
-    
+
     mpIDEA->SetKey(iCipher::DECRYPT, cHashedKey128(key, rsa.GetBlockSizePlain()));
     mCryptoArchive.Start(mpArchive, mpIDEA);
 
@@ -600,21 +600,21 @@ void cRSAArchive::SetRead(cArchive* pSrcArchive, const cRSAPublicKey* pPublicKey
 void cRSAArchive::SetRead(cArchive* pSrcArchive, const cRSAPrivateKey* pPrivateKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_READING;
-    mpArchive = pSrcArchive;
+    mAction      = MA_READING;
+    mpArchive    = pSrcArchive;
     mpPrivateKey = pPrivateKey;
-    mpPublicKey = 0;
+    mpPublicKey  = 0;
 
     cRSA  rsa(*mpPrivateKey);
-    int8* key = new int8[rsa.GetBlockSizePlain()];
+    int8* key          = new int8[rsa.GetBlockSizePlain()];
     int8* encryptedKey = new int8[rsa.GetBlockSizeCipher()];
 
     mpArchive->ReadBlob(encryptedKey, rsa.GetBlockSizeCipher());
     rsa.SetDecrypting(mpPrivateKey);
     rsa.ProcessBlock(encryptedKey, key);
-    
+
     mpIDEA->SetKey(iCipher::DECRYPT, cHashedKey128(key, rsa.GetBlockSizePlain()));
     mCryptoArchive.Start(mpArchive, mpIDEA);
 
@@ -648,7 +648,7 @@ int cRSAArchive::Write(const void* pSrc, int count)
 
 bool cRSAArchive::EndOfFile()
 {
-    ASSERT(mAction == MA_READING);  // why would you call this if not reading?
+    ASSERT(mAction == MA_READING); // why would you call this if not reading?
     if (mAction != MA_READING)
         return true;
 
@@ -659,33 +659,29 @@ bool cRSAArchive::EndOfFile()
 
 
 ///////////////////////////////////////////////////////////////////////////////
-// class cElGamalSigArchive 
+// class cElGamalSigArchive
 
 cElGamalSigArchive::cElGamalSigArchive()
+    : mAction(MA_UNSTARTED), mpArchive(0), mpElGamal(0), mpPublicKey(0), mpPrivateKey(0)
 {
-    mAction = MA_UNSTARTED;
-    mpArchive = 0;
-    mpPublicKey = 0;
-    mpPrivateKey = 0;
-    mpElGamal = 0;
 }
 
 cElGamalSigArchive::~cElGamalSigArchive()
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
     delete mpElGamal;
 }
 
 void cElGamalSigArchive::SetWrite(cArchive* pDestArchive, const cElGamalSigPrivateKey* pPrivateKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_WRITING;
-    mpArchive = pDestArchive;
+    mAction      = MA_WRITING;
+    mpArchive    = pDestArchive;
     mpPrivateKey = pPrivateKey;
-    mpPublicKey = 0;
+    mpPublicKey  = 0;
 
     mpElGamal = new cElGamalSig(*mpPrivateKey);
     mpElGamal->SetSigning(mpPrivateKey);
@@ -707,17 +703,17 @@ void cElGamalSigArchive::FlushWrite()
 void cElGamalSigArchive::SetRead(cArchive* pSrcArchive, const cElGamalSigPublicKey* pPublicKey)
 {
     ASSERT(mAction == MA_UNSTARTED || mAction == MA_FINISHED || mAction == MA_READING);
-        // check we did not leave a buffer unwritten
+    // check we did not leave a buffer unwritten
 
-    mAction = MA_READING;
-    mpArchive = pSrcArchive;
-    mpPublicKey = pPublicKey;
+    mAction      = MA_READING;
+    mpArchive    = pSrcArchive;
+    mpPublicKey  = pPublicKey;
     mpPrivateKey = 0;
 
     mpElGamal = new cElGamalSig(*mpPublicKey);
 
     mpElGamal->SetVerifying(mpPublicKey);
-    
+
     mCryptoArchive.Start(mpArchive, mpElGamal);
 }
 
@@ -742,10 +738,9 @@ int cElGamalSigArchive::Write(const void* pSrc, int count)
 
 bool cElGamalSigArchive::EndOfFile()
 {
-    ASSERT(mAction == MA_READING);  // why would you call this if not reading?
+    ASSERT(mAction == MA_READING); // why would you call this if not reading?
     if (mAction != MA_READING)
         return true;
 
     return mCryptoArchive.EndOfFile();
 }
-
