@@ -1,31 +1,31 @@
 //
 // The developer of the original code and/or files is Tripwire, Inc.
-// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
+// Portions created by Tripwire, Inc. are copyright (C) 2000-2018 Tripwire,
 // Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
 // reserved.
-// 
+//
 // This program is free software.  The contents of this file are subject
 // to the terms of the GNU General Public License as published by the
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version.  You may redistribute it and/or modify it
 // only in compliance with the GNU General Public License.
-// 
+//
 // This program is distributed in the hope that it will be useful.
 // However, this program is distributed AS-IS WITHOUT ANY
 // WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
 // FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
 // for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 // USA.
-// 
+//
 // Nothing in the GNU General Public License or any other license to use
 // the code or files shall permit you to use Tripwire's trademarks,
 // service marks, or other intellectual property without Tripwire's
 // prior written consent.
-// 
+//
 // If you have any questions, please contact Tripwire, Inc. at either
 // info@tripwire.org or www.tripwire.org.
 //
@@ -36,6 +36,7 @@
 #include "tw/stdtw.h"
 #include <sys/stat.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include "tw/fcoreport.h"
 #include "fco/fcospecimpl.h"
@@ -56,10 +57,10 @@
 #include "tw/fcoreportutil.h"
 #include "tw/headerinfo.h"
 
-#ifdef FIXED_TRV_TEST_SUITE
+//#ifdef FIXED_TRV_TEST_SUITE
 
-void MakeFile( TSTRING& fcoNameMakeMe );
-void MakeDir( const TCHAR* const lpszDirName );
+void MakeFile(TSTRING& fcoNameMakeMe);
+void MakeDir(const TCHAR* const lpszDirName);
 
 // we use this instead of TraceContents() so we can test the report iterators.
 static void TraceReport(const cFCOReport& r, cDebug& d)
@@ -68,31 +69,31 @@ static void TraceReport(const cFCOReport& r, cDebug& d)
     r.GetErrorQueue()->TraceContents();
 
     cFCOReportGenreIter genreIter(r);
-    int genreCount = 0;
+    int                 genreCount = 0;
 
     for (genreIter.SeekBegin(); !genreIter.Done(); genreIter.Next())
     {
         d.TraceDebug("> Genre [%d]:\n", genreCount);
 
         cFCOReportSpecIter specIter(genreIter);
-        int ct = 0;
+        int                ct = 0;
 
-        for(specIter.SeekBegin(); ! specIter.Done(); specIter.Next(), ct++)
+        for (specIter.SeekBegin(); !specIter.Done(); specIter.Next(), ct++)
         {
             d.TraceDebug(">>> Spec [%d]:\n", ct);
-            ASSERT(specIter.GetSpec());
+            TEST(specIter.GetSpec());
             specIter.GetSpec()->TraceContents();
             specIter.GetErrorQueue()->TraceContents();
 
             d.TraceDebug(">>> Added Files:\n");
             specIter.GetAddedSet()->TraceContents();
             d.TraceDebug(">>> Removed Files:\n");
-            specIter.GetRemovedSet()->TraceContents ();
+            specIter.GetRemovedSet()->TraceContents();
 
             // trace out changed files
             cFCOReportChangeIter changeIter(specIter);
-            int changeCtr = 0;
-            for(changeIter.SeekBegin(); ! changeIter.Done(); changeIter.Next(), changeCtr++)
+            int                  changeCtr = 0;
+            for (changeIter.SeekBegin(); !changeIter.Done(); changeIter.Next(), changeCtr++)
             {
                 d.TraceDebug(">>>>> Changed fco [%d]\n", changeCtr);
                 d.TraceDebug(">>>>>   Old FCO:\n");
@@ -105,8 +106,29 @@ static void TraceReport(const cFCOReport& r, cDebug& d)
     }
 }
 
+/*
+ //
+ // basic functionality
+ //
+ void DisplayReportAndHaveUserUpdateIt( const TSTRING& edName, ReportingLevel level = FULL_REPORT ); //throw (eFSServices, eTextReportViewer, eInternal);
+ // outputs the given report to a temp file, opens an editor, has
+ // the user view changes to the database, and, by selecting FCO entries,
+ // chooses which changes to write to the database.  Unchecked entries
+ // are removed from the report
+ // edName is the name of the editor to use to update the report
+ 
+ virtual void PrintTextReport( const TSTRING& strFilename, ReportingLevel level = FULL_REPORT ); //throw (eTextReportViewer);
+ // if strFilename is "-", will print to TCOUT
+ virtual void PrintTextReport( TOSTREAM& ostr, ReportingLevel level = FULL_REPORT ); //throw (eTextReportViewer);
+ // prints the report to the specified ostream
+ */
+
+
 void TestTextReportViewer()
 {
+    skip("TestTextReportViewer needs to be cleaned up & fixed, currently disabled");
+
+#if 0
     cFCOReport  report;
     cFCOReportGenreIter genreIter(report);
     cFCOReportSpecIter specIter(genreIter);
@@ -119,7 +141,7 @@ void TestTextReportViewer()
     try
     {
         iFSServices* pFSServices = iFSServices::GetInstance();
-        ASSERT( pFSServices );
+        TEST( pFSServices );
 
         TSTRING fcoNameTempDir;
         pFSServices->GetTempDirName( fcoNameTempDir );
@@ -127,9 +149,9 @@ void TestTextReportViewer()
         fcoNameSpec1 = fcoNameTempDir += _T("SPEC1/");
         fcoNameSpec2 = fcoNameTempDir += _T("SPEC2/");
         
-        pFSServices->Mkdir( fcoNameTempDir );
-        pFSServices->Mkdir( fcoNameSpec1.AsString() );
-        pFSServices->Mkdir( fcoNameSpec2.AsString() );
+        mkdir( fcoNameTempDir.c_str(), 0777 );
+        mkdir( fcoNameSpec1.AsString().c_str(), 0777 );
+        mkdir( fcoNameSpec2.AsString().c_str(), 0777 );
         
         fcoNameTempFile = fcoNameTempDir += _T("twtempXXXXXX");
         pFSServices->MakeTempFilename( fcoNameTempFile );
@@ -137,12 +159,12 @@ void TestTextReportViewer()
     catch(eFSServices& /* e */)
     {
         // TODO: properly handle error
-        ASSERT( false );
+        TEST( false );
     }
-
+ 
     // need two prop calcs because.....
     // if cFSPropCalc::VisitFSObject succeeds, cFSPropCalc stores the FCO in
-    // an internal set (why, I don't know), and the cFCOSet ASSERTs that the same 
+    // an internal set (why, I don't know), and the cFCOSet TESTs that the same 
     // FCO isn't inserted more than once.  But since we visit changed FCOs twice 
     // in this test routine, we need two calcs.  Make sense?  Oh, well.
     cFSPropCalc* pPropCalc = new cFSPropCalc;
@@ -153,7 +175,7 @@ void TestTextReportViewer()
     cFCOSpecImpl*    pSpec          = new cFCOSpecImpl( fcoNameSpec1.AsString(), NULL, pStopPts);
     cFCOSpecAttr* pAttr         = new cFCOSpecAttr;
     
-    
+ 
     cFCOPropVector v;    
     for( int i = 0; i < 32; i++ )
         v.AddItem( i );
@@ -161,7 +183,6 @@ void TestTextReportViewer()
     pPropCalc->SetPropVector(v);
     pPropCalc2->SetPropVector(v);
 
-
     TSTRING fcoNameMakeMe;
     fcoNameMakeMe = fcoNameSpec1.AsString() + _T("/added_fileXXXXXX");
     MakeFile( fcoNameMakeMe );
@@ -172,9 +193,10 @@ void TestTextReportViewer()
     // MakeTempFile can't handle strings with escaped quotes, so we'll have to do this ourselves
     fcoNameMakeMe = fcoNameSpec1.AsString() + _T("/\"quoted\\_and_backslashed_file1\"");    
     //TOFSTREAM file1( fcoNameMakeMe.c_str() );
-    //ASSERT( file1 );
+    //TEST( file1 );
     //file1.close();
 
+  
     cFSObject*  addedFCO2       = new cFSObject( cFCOName(fcoNameMakeMe) );
     //pPropCalc->VisitFSObject( *addedFCO2 );
     
@@ -182,7 +204,7 @@ void TestTextReportViewer()
     // MakeTempFile can't handle strings with escaped quotes, so we'll have to do this ourselves
     fcoNameMakeMe = fcoNameSpec1.AsString() + _T("/quoted_file\"2\"XXXXXX");
     //TOFSTREAM file2( fcoNameMakeMe.c_str() );
-    //ASSERT( file2 );
+    //TEST( file2 );
     //file2.close();
 
     cFSObject*  addedFCO3       = new cFSObject( cFCOName(fcoNameMakeMe) );
@@ -199,6 +221,7 @@ void TestTextReportViewer()
     MakeFile( fcoNameMakeMe );
     cFSObject*  removedFCO2     = new cFSObject( cFCOName(fcoNameMakeMe) );
     pPropCalc->VisitFSObject( *removedFCO2 );
+    
 
     pSpec->SetStartPoint( fcoNameSpec1 );
     pAttr->SetName( fcoNameSpec1.AsString() );
@@ -207,7 +230,9 @@ void TestTextReportViewer()
     report.AddSpec(0x00020001, pSpec, pAttr, &specIter); // TODO:bam - use cFS::Genre
     pAttr->Release();    
 
-    
+    TEST(specIter.GetAddedSet());
+    TEST(specIter.GetRemovedSet());
+
     specIter.GetAddedSet()->Insert(addedFCO);
     specIter.GetAddedSet()->Insert(addedFCO2);
     specIter.GetAddedSet()->Insert(addedFCO3);
@@ -234,6 +259,7 @@ void TestTextReportViewer()
     changedPropVector1.AddItem(cFSPropSet::PROP_UID);
     report.AddChangedFCO(specIter, oldChangedFCO, newChangedFCO, changedPropVector1);
 
+    
     // make changed FCO2
     cFCOPropVector changedPropVector2;
 
@@ -280,7 +306,7 @@ void TestTextReportViewer()
     specIter.GetAddedSet()->Insert(addedFCO5);
     specIter.GetRemovedSet()->Insert(removedFCO5);
 
-        
+    
 
     // make changed FCO3
     cFCOPropVector changedPropVector3;
@@ -321,14 +347,13 @@ void TestTextReportViewer()
     specIter.Next();
     //specIter.GetErrorQueue()->AddError(2, "this is an \"/etc2\" spec error",NULL);
 
-
     d.TraceDebug(_T("\n======================================================\nStart PrintTextReport...\n======================================================\n\n\n"));
         
     TSTRING tstrEmpty( _T("") );
     cFCOReportHeader rhi;
     cFCOReportUtil::FinalizeReport( report );
-    cTextReportViewer trv;
-    trv.DisplayReportAndHaveUserUpdateIt( rhi, report, _T("") );
+    cTextReportViewer trv(rhi, report);
+    trv.DisplayReportAndHaveUserUpdateIt( _T("") );
 
             // test writing of USID
             cFileArchive outFile;
@@ -354,20 +379,20 @@ void TestTextReportViewer()
 
             d.TraceDebug("Read in serialized report:\n");
             //TraceReport(inReport, d);
-            trv.PrintTextReport( rhi, inReport, TSTRING( TEMP_DIR _T( "/test2.txt" ) ) );    
+            trv.PrintTextReport(TSTRING( TwTestPath("test2.txt" ) ) );
 
             //TODO: this does not work any more
             //trv.LaunchEditorOnFile( TSTRING( TEMP_DIR _T("/test2.txt") ), _T("") );
 
 
     // look at results
-    trv.PrintTextReport( rhi, report, fcoNameTempFile );    
+    trv.PrintTextReport(fcoNameTempFile );
     //TODO: this does not work any more
     //cTextReportViewer::LaunchEditorOnFile( fcoNameTempFile, _T("") );
 
     
     iFSServices* pFSServices = iFSServices::GetInstance();
-    ASSERT( pFSServices );
+    TEST( pFSServices );
     pFSServices->FileDelete( addedFCO->GetName().AsString() );
     pFSServices->FileDelete( addedFCO2->GetName().AsString() );
     pFSServices->FileDelete( addedFCO3->GetName().AsString() );
@@ -382,8 +407,8 @@ void TestTextReportViewer()
     pFSServices->FileDelete( fcoNameTempFile );
 
     // don't remove TEMP_DIR since other people may be using it
-    pFSServices->Rmdir( fcoNameSpec1.AsString() );
-    pFSServices->Rmdir( fcoNameSpec2.AsString() );
+    rmdir( fcoNameSpec1.AsString().c_str() );
+    rmdir( fcoNameSpec2.AsString().c_str() );
 
     pSpec->Release();
     pSpec2->Release();
@@ -404,58 +429,54 @@ void TestTextReportViewer()
     newChangedFCO3->Release();
     oldChangedFCO4->Release();
     newChangedFCO4->Release();
+#endif
 
     return;
 }
 
-void MakeFile( TSTRING& strNameMakeMe )
-{
-    try
-    {
-        iFSServices* pFSServices = iFSServices::GetInstance(); ASSERT( pFSServices );
-        pFSServices->MakeTempFilename( strNameMakeMe );
-
-        std::string strA;
-        for( TSTRING::iterator i = strNameMakeMe.begin(); i != strNameMakeMe.end(); i++ )
-        {
-            char ach[4];
-            ASSERT( MB_CUR_MAX <= 4 );
-
-            int n = wctomb( ach, *i );
-            ASSERT( n != -1 );
-            
-            for( int j = 0; j < n; j++ )
-                strA += ach[j];
-        }
-
-        TOFSTREAM file( strA.c_str() );
-        ASSERT( file );
-        file.close();
-    }
-    catch( eFSServices e )
-    {
-        ASSERT( false );
-    }
-    catch( ... )
-    {
-        ASSERT( false );
-    }
-}
-
-void MakeDir( const TCHAR* const lpszDirName )
+void MakeFile(TSTRING& strNameMakeMe)
 {
     try
     {
         iFSServices* pFSServices = iFSServices::GetInstance();
-        TSTRING newdir(lpszDirName);
+        TEST(pFSServices);
+        pFSServices->MakeTempFilename(strNameMakeMe);
 
-        pFSServices->Mkdir( newdir );
+        std::string strA;
+        for (TSTRING::iterator i = strNameMakeMe.begin(); i != strNameMakeMe.end(); ++i)
+        {
+            char ach[6];
+            TEST(MB_CUR_MAX <= 6);
+
+            int n = wctomb(ach, *i);
+            TEST(n != -1);
+
+            for (int j = 0; j < n; j++)
+                strA += ach[j];
+        }
+
+        TOFSTREAM file(strA.c_str());
+        TEST(file);
+        file.close();
     }
-    catch( eFSServices e )
+    catch (eFSServices e)
     {
-        ASSERT( false );
+        TEST(false);
+    }
+    catch (...)
+    {
+        TEST(false);
     }
 }
 
-#endif //FIXED_TRV_TEST_SUITE
+void MakeDir(const TCHAR* const lpszDirName)
+{
+    TEST(0 == mkdir(lpszDirName, 0777))
+}
 
+//#endif //FIXED_TRV_TEST_SUITE
+
+void RegisterSuite_TextReportViewer()
+{
+    RegisterTest("TextReportViewer", "Basic", TestTextReportViewer);
+}
